@@ -77,7 +77,7 @@ class UploadedFile:
     """File content as `io.BytesIO`_.
 
     .. _io.BytesIO:
-            https://docs.python.org/3/library/io.html#io.BytesIO
+        https://docs.python.org/3/library/io.html#io.BytesIO
     """
 
 
@@ -91,18 +91,14 @@ class Client:
         username: LimeSurvey user name.
         password: LimeSurvey password.
         requests_session: A `requests.Session`_ object.
-        auth_plugin: Name of the `plugin` to use for authentication.
-            For example, `AuthLDAP`_. Defaults to using the internal database
-            (`Authdb`_).
+        auth_plugin: Name of the :ls_manual:`plugin <Authentication_plugins>` to use for
+            authentication. For example,
+            :ls_manual:`AuthLDAP <Authentication_plugins#LDAP>`. Defaults to using the
+            :ls_manual:`internal database <Authentication_plugins#Internal_database>`
+            (``"Authdb"``).
 
     .. _requests.Session:
-        https://docs.python-requests.org/en/latest/api/#requests.Session
-    .. _plugin: https://manual.limesurvey.org/Authentication_plugins
-    .. _Authdb: https://manual.limesurvey.org/Authentication_plugins#Internal_database
-    .. _AuthLDAP: https://manual.limesurvey.org/Authentication_plugins#LDAP
-
-    .. _requests.Session:
-        https://docs.python-requests.org/en/latest/api/#requests.Session
+        https://requests.readthedocs.io/en/latest/api/#request-sessions
     """
 
     session_class = Session
@@ -113,7 +109,7 @@ class Client:
         username: str,
         password: str,
         *,
-        requests_session: requests.Session = requests.session(),
+        requests_session: requests.Session | None = None,
         auth_plugin: str = "Authdb",
     ) -> None:
         """Create a LimeSurvey Python API client."""
@@ -121,7 +117,7 @@ class Client:
             url,
             username,
             password,
-            requests_session=requests_session,
+            requests_session=requests_session or requests.session(),
             auth_plugin=auth_plugin,
         )
 
@@ -135,8 +131,8 @@ class Client:
 
     def __exit__(
         self,
-        type: type[BaseException] | None,
-        value: BaseException | None,
+        exc_type: type[BaseException] | None,
+        exc_value: BaseException | None,
         traceback: TracebackType | None,
     ) -> None:
         """Safely exit the client context."""
@@ -147,6 +143,17 @@ class Client:
         """Low-level RPC session."""
         return self.__session
 
+    def get_fieldmap(self, survey_id: int) -> dict:
+        """Get fieldmap for a survey.
+
+        Args:
+            survey_id: ID of survey to get fieldmap for.
+
+        Returns:
+            Dictionary mapping response keys to LimeSurvey internal representation.
+        """
+        return self.__session.get_fieldmap(survey_id)
+
     def activate_survey(self, survey_id: int) -> dict[str, Any]:
         """Activate a survey.
 
@@ -192,6 +199,7 @@ class Client:
     def add_participants(
         self,
         survey_id: int,
+        *,
         participant_data: Sequence[Mapping[str, Any]],
         create_tokens: bool = True,
     ) -> list[dict[str, Any]]:
@@ -256,24 +264,60 @@ class Client:
             participant_ids,
         )
 
-    def _map_response_keys(
+    def _get_question_mapping(
         self,
         survey_id: int,
+    ) -> dict[str, dict[str, Any]]:
+        """Get question mapping.
+
+        Args:
+            survey_id: Survey ID.
+
+        Returns:
+            Question mapping.
+        """
+        return {q["title"]: q for q in self.list_questions(survey_id)}
+
+    @staticmethod
+    def _map_response_keys(
         response_data: Mapping[str, Any],
+        question_mapping: dict[str, dict[str, Any]],
     ) -> dict[str, Any]:
         """Converts response keys to LimeSurvey's internal representation.
 
         Args:
-            survey_id: The survey ID where the response belongs.
             response_data: The response mapping.
+            question_mapping: A mapping of question titles to question dictionaries.
 
         Returns:
             A new dictionary with the keys mapped to the <SID>X<GID>X<QID> format.
-        """
-        qs = {q["title"]: q for q in self.list_questions(survey_id)}
 
+        >>> mapped_keys = Client._map_response_keys(
+        ...     {"Q1": "foo", "Q2": "bar", "BAZ": "qux"},
+        ...     {
+        ...         "Q1": {
+        ...             "title": "Q1",
+        ...             "qid": 9,
+        ...             "gid": 7,
+        ...             "sid": 123,
+        ...         },
+        ...         "Q2": {
+        ...             "title": "Q2",
+        ...             "qid": 10,
+        ...             "gid": 7,
+        ...             "sid": 123,
+        ...         },
+        ...     },
+        ... )
+        >>> mapped_keys
+        {'123X7X9': 'foo', '123X7X10': 'bar', 'BAZ': 'qux'}
+        """
         return {
-            ("{sid}X{gid}X{qid}".format(**qs[key]) if key in qs else key): value
+            (
+                "{sid}X{gid}X{qid}".format(**question_mapping[key])
+                if key in question_mapping
+                else key
+            ): value
             for key, value in response_data.items()
         }
 
@@ -290,6 +334,19 @@ class Client:
         """
         return self.__session.add_group(survey_id, title, description)
 
+    def _add_response(self, survey_id: int, response_data: Mapping[str, Any]) -> int:
+        """Add a single response to a survey.
+
+        Args:
+            survey_id: Survey to add the response to.
+            response_data: Single response as a mapping from question codes of the form
+                <SID>X<GID>X<QID> to response values.
+
+        Returns:
+            ID of the new response.
+        """
+        return int(self.__session.add_response(survey_id, response_data))
+
     def add_response(self, survey_id: int, response_data: Mapping[str, Any]) -> int:
         """Add a single response to a survey.
 
@@ -301,8 +358,9 @@ class Client:
             ID of the new response.
         """
         # Transform question codes to the format LimeSurvey expects
-        data = self._map_response_keys(survey_id, response_data)
-        return int(self.__session.add_response(survey_id, data))
+        questions = self._get_question_mapping(survey_id)
+        data = self._map_response_keys(response_data, questions)
+        return self._add_response(survey_id, data)
 
     def add_responses(
         self,
@@ -319,11 +377,27 @@ class Client:
             IDs of the new responses.
         """
         ids = []
+        questions = self._get_question_mapping(survey_id)
         for response in responses:
-            response_id = self.add_response(survey_id, response)
+            data = self._map_response_keys(response, questions)
+            response_id = self._add_response(survey_id, data)
             ids.append(response_id)
         return ids
 
+    def update_response(self, survey_id: int, response_data: dict[str, Any]) -> bool:
+        """Update a response.
+
+        Args:
+            survey_id: Survey to update the response in.
+            response_data: Response data to update.
+
+        Returns:
+            True if the response was updated, False otherwise.
+        """
+        questions = self._get_question_mapping(survey_id)
+        data = self._map_response_keys(response_data, questions)
+        return self.__session.update_response(survey_id, data)
+
     def copy_survey(self, survey_id: int, name: str) -> int:
         """Copy a survey.
 
@@ -445,21 +519,21 @@ class Client:
                     fields,
                 ),
             )
-        else:
-            return base64.b64decode(
-                self.__session.export_responses_by_token(
-                    survey_id,
-                    enums.ResponsesExportFormat(file_format),
-                    token,
-                    language,
-                    enums.SurveyCompletionStatus(completion_status),
-                    enums.HeadingType(heading_type),
-                    enums.ResponseType(response_type),
-                    from_response_id,
-                    to_response_id,
-                    fields,
-                ),
-            )
+
+        return base64.b64decode(
+            self.__session.export_responses_by_token(
+                survey_id,
+                enums.ResponsesExportFormat(file_format),
+                token,
+                language,
+                enums.SurveyCompletionStatus(completion_status),
+                enums.HeadingType(heading_type),
+                enums.ResponseType(response_type),
+                from_response_id,
+                to_response_id,
+                fields,
+            ),
+        )
 
     def save_responses(
         self,
@@ -712,6 +786,8 @@ class Client:
     def get_default_theme(self) -> str:
         """Get the global default theme.
 
+        Calls :rpc_method:`get_site_settings("defaulttheme") <get_site_settings>`.
+
         Returns:
             The name of the theme.
         """
@@ -720,6 +796,8 @@ class Client:
     def get_site_name(self) -> str:
         """Get the site name.
 
+        Calls :rpc_method:`get_site_settings("sitename") <get_site_settings>`.
+
         Returns:
             The name of the site.
         """
@@ -728,6 +806,8 @@ class Client:
     def get_default_language(self) -> str:
         """Get the default site language.
 
+        Calls :rpc_method:`get_site_settings("defaultlang") <get_site_settings>`.
+
         Returns:
             A string representing the language.
         """
@@ -736,9 +816,12 @@ class Client:
     def get_available_languages(self) -> list[str] | None:
         """Get the list of available languages.
 
+        Calls
+        :rpc_method:`get_site_settings("restrictToLanguages") <get_site_settings>`.
+
         Returns:
             Either a list of strings for the available languages or None if there are
-                no restrictions.
+            no restrictions.
         """
         langs: str = self._get_site_setting("restrictToLanguages")
 
@@ -931,11 +1014,12 @@ class Client:
     def list_participants(
         self,
         survey_id: int,
+        *,
         start: int = 0,
         limit: int = 10,
         unused: bool = False,
         attributes: Sequence[str] | bool = False,
-        conditions: Mapping[str, Any] | None = {},
+        conditions: Mapping[str, Any] | None = None,
     ) -> list[dict[str, Any]]:
         """Get participants in a survey.
 
@@ -956,7 +1040,7 @@ class Client:
             limit,
             unused,
             attributes,
-            conditions,
+            conditions or {},
         )
 
     def list_users(self) -> list[dict[str, Any]]:
