@@ -1,5 +1,7 @@
 """RPC methods."""
 
+from __future__ import annotations
+
 from typing import Any, Callable
 
 
@@ -11,11 +13,22 @@ class Method:
         self.__caller = caller
         self.__name = name
 
-    def __getattr__(self, name: str) -> "Method":  # noqa: ANN101
-        """Get nested method."""
+    def __getattr__(self, name: str) -> Method:
+        """Get nested method.
+
+        Args:
+            name: Method name.
+
+        Returns:
+            A new instance of Method for the nested call.
+
+        >>> method = Method(print, "some_method")
+        >>> method.nested("x", "y")
+        some_method.nested x y
+        """
         return Method(self.__caller, f"{self.__name}.{name}")
 
-    def __call__(self, *params: Any) -> Any:  # noqa: ANN101
+    def __call__(self, *params: Any) -> Any:  # noqa: ANN401
         """Call RPC method.
 
         Args:
@@ -23,5 +36,9 @@ class Method:
 
         Returns:
             An RPC result.
+
+        >>> method = Method(print, "some_method")
+        >>> method(1, "a")
+        some_method 1 a
         """
         return self.__caller(self.__name, *params)
