@@ -1,15 +1,18 @@
 """Low level wrapper for connecting to the LSRC2."""
+
+from __future__ import annotations
+
 import logging
 import random
 from types import TracebackType
-from typing import Any, Optional, Type, TypeVar
+from typing import Any, TypeVar
 
 import requests
 
 from citric.exceptions import (
+    LimeSurveyApiError,
     LimeSurveyError,
     LimeSurveyStatusError,
-    LimeSurveyApiError,
     ResponseMismatchError,
 )
 from citric.method import Method
@@ -21,19 +24,25 @@ logger = logging.getLogger(__name__)
 class Session:
     """LimeSurvey RemoteControl 2 session.
 
+    Upon creation, retrieves a session key with
+    :ls_manual:`get_session_key <RemoteControl_2_API#get_session_key>` and stores it in
+    the `key`_ attribute. The key is released upon session `closure`_.
+
     Args:
         url: LimeSurvey Remote Control endpoint.
         username: LimeSurvey user name.
         password: LimeSurvey password.
         requests_session: A `requests.Session`_ object.
-        auth_plugin: Name of the `plugin` to use for authentication.
-            For example, `AuthLDAP`_. Defaults to using the internal database
+        auth_plugin: Name of the :ls_manual:`plugin <Authentication_plugins>` to use for
+            authentication. For example,
+            :ls_manual:`AuthLDAP <Authentication_plugins#LDAP>`. Defaults to using the
+            :ls_manual:`internal database <Authentication_plugins#Internal_database>`
             (``"Authdb"``).
 
     .. _requests.Session:
-        https://docs.python-requests.org/en/latest/api/#requests.Session
-    .. _plugin: https://manual.limesurvey.org/Authentication_plugins
-    .. _AuthLDAP: https://manual.limesurvey.org/Authentication_plugins#LDAP
+        https://requests.readthedocs.io/en/latest/api/#request-sessions
+    .. _key: #citric.session.Session.key
+    .. _closure: #citric.session.Session.close
     """
 
     _headers = {
@@ -49,15 +58,15 @@ class Session:
         username: str,
         password: str,
         *,
-        requests_session: requests.Session = requests.session(),
+        requests_session: requests.Session | None = None,
         auth_plugin: str = "Authdb",
     ) -> None:
         """Create a LimeSurvey RPC session."""
         self.url = url
-        self._session = requests_session
+        self._session = requests_session or requests.session()
         self._session.headers.update(self._headers)
 
-        self.__key: Optional[str] = self.get_session_key(
+        self.__key: str | None = self.get_session_key(
             username,
             password,
             auth_plugin,
@@ -71,7 +80,7 @@ class Session:
         return self.__closed
 
     @property
-    def key(self) -> Optional[str]:
+    def key(self) -> str | None:
         """RPC session key."""
         return self.__key
 
@@ -79,7 +88,7 @@ class Session:
         """Magic method dispatcher."""
         return Method(self.rpc, name)
 
-    def rpc(self, method: str, *params: Any) -> Any:
+    def rpc(self, method: str, *params: Any) -> Any:  # noqa: ANN401
         """Execute RPC method on LimeSurvey, with optional token authentication.
 
         Any method, except for `get_session_key`.
@@ -92,15 +101,18 @@ class Session:
             An RPC result.
         """
         if method == "get_session_key" or method.startswith("system."):
-            result = self._invoke(self._session, self.url, method, *params)
-        # Methods requiring authentication
-        else:
-            result = self._invoke(self._session, self.url, method, self.key, *params)
+            return self._invoke(self._session, self.url, method, *params)
 
-        return result
+        # Methods requiring authentication
+        return self._invoke(self._session, self.url, method, self.key, *params)
 
     @staticmethod
-    def _invoke(session: requests.Session, url: str, method: str, *params: Any) -> Any:
+    def _invoke(
+        session: requests.Session,
+        url: str,
+        method: str,
+        *params: Any,
+    ) -> Any:  # noqa: ANN401
         """Execute a LimeSurvey RPC with a JSON payload.
 
         Args:
@@ -155,7 +167,11 @@ class Session:
         return result
 
     def close(self) -> None:
-        """Close RPC session."""
+        """Close RPC session.
+
+        Releases the session key with
+        :ls_manual:`release_session_key <RemoteControl_2_API#release_session_key>`.
+        """
         self.release_session_key()
         self._session.close()
         self.__key = None
@@ -171,15 +187,15 @@ class Session:
 
     def __exit__(
         self,
-        type: Optional[Type[BaseException]],
-        value: Optional[BaseException],
-        traceback: Optional[TracebackType],
+        exc_type: type[BaseException] | None,
+        exc_value: BaseException | None,
+        traceback: TracebackType | None,
     ) -> None:
         """Safely exit an RPC session.
 
         Args:
-            type: Exception class.
-            value: Exception instance.
+            exc_type: Exception class.
+            exc_value: Exception instance.
             traceback: Error traceback.
         """
         self.close()
